<?php

declare(strict_types=1);

namespace Drupal\package_manager\Event;

/**
 * Event fired after staged changes are synced to the active directory.
 */
final class PostApplyEvent extends SandboxEvent {
}
